@@ -327,6 +327,25 @@ class FacileToolkit2:
         )
         return [self.sl.get_text(element) for element in webelements]
 
+    @keyword
+    def get_text_from_locators(self, *webelements, timeout=None, error=None):
+        """
+        Takes in input a Locators array and
+        returns a string array containing the stripped texts retrieved from the webelements
+        """
+        self.set_selenium_library()
+        texts = []
+        self._wait_until(
+            lambda: [texts.extend(self.get_texts(element)) for element in webelements],
+            "Error retrieving element texts",
+            timeout, error
+        )
+        return texts
+
+    def get_texts(self, locator):
+        self.set_selenium_library()
+        return [self.sl.get_text(element) for element in self.sl.find_elements(locator)]
+    
     @keyword
     def generate_random_number_as_string(self, minimum, maximum):
         """
@@ -383,8 +402,9 @@ class FacileToolkit2:
             timeout = self.ajax_timeout
         if is_noney(wait_active):
             wait_active = self.ajax_activation
-        BuiltIn().run_keyword_and_ignore_error("wait_ajax_activation", wait_active)
-        self.sl.wait_for_condition('if(typeof(jQuery) == "function") {return jQuery.active == 0} return false', timeout)
+        is_active = BuiltIn().run_keyword_and_return_status("wait_ajax_activation", wait_active)
+        if is_active:
+            self.sl.wait_for_condition('if(typeof(jQuery) == "function") {return jQuery.active == 0} return false', timeout)
 
     @keyword
     def wait_ajax_activation(self, timeout=None):
@@ -428,11 +448,11 @@ class FacileToolkit2:
     @keyword
     def select_checkboxes(self, *locators, timeout="60s"):
         for locator in locators:
-            self.wait_ajax(timeout)
+            self.wait_ajax_optional(timeout)
             if BuiltIn().run_keyword_and_return_status("checkbox_should_not_be_selected", locator):
                 self.click_js(locator)
         if timeout is not None:
-            self.wait_ajax(timeout)
+            self.wait_ajax_optional(timeout)
         self.should_be_checked(*locators)
 
     @keyword
@@ -706,6 +726,12 @@ class FacileToolkit2:
     def val_jquery(self, locator, value):
         self.execute_jquery_method_on_webelement(locator, "val('%s');" % value)
 
+
+    @keyword
+    def is_visible(self, locator, timeout="1s"):
+        self.set_selenium_library()
+        return BuiltIn().run_keyword_and_return_status("wait_until_element_is_visible", locator, timeout)
+
     @staticmethod
     @keyword
     def return_2nd_if_1st_is_none(first, second):
